@@ -21,13 +21,21 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 '''
 
+from __future__ import print_function
+
 import struct
+import sys
+
+if sys.version_info[0] < 3:
+    _map_ord = lambda it: map(ord, it)
+else:
+    _map_ord = iter
 
 def process_file(filename):
     try:
         f = open(filename, 'rb')
     except IOError as e:
-        print >> sys.stderr, 'Unable to open %s: %s' % (filename, e)
+        print('Unable to open %s: %s' % (filename, e), file=sys.stderr)
         return
 
     with f:
@@ -39,11 +47,11 @@ def process_file(filename):
 
         while True:
             tag = f.read(1)
-            if tag == '':
+            if tag == b'':
                 break
 
             if ord(tag) > 128:
-                if tag == '\x90':
+                if tag == b'\x90':
                     # Emit the current element and close the last layer
                     emit_element(svg_element)
                     emit_element('</g>')
@@ -52,7 +60,7 @@ def process_file(filename):
                     layer = 'layer%d' % (ord(f.read(1)) + 1)
                     timestamp = 0
                     svg_element = '<g inkscape:groupmode="layer" id="%s">' % layer
-                elif tag == '\x88':
+                elif tag == b'\x88':
                     # Read the timestamp next
                     timestamp += ord(f.read(1)) * 20
                 else:
@@ -73,14 +81,14 @@ def process_file(filename):
                     points = ' '.join(','.join(map(str, e)) for e in coords)
                     svg_element = '<polyline points="%s" dm:timestamp="%s" />' % (points, timestamp)
             else:
-                print >> sys.stderr, 'Unsupported tag: %s\n' % tag
+                print('Unsupported tag: %s\n' % tag, file=sys.stderr)
 
         # Emit the footer to finish it off
-        print '\n</svg>\n'
+        print('\n</svg>\n')
 
 
 def read_point(f, ymax):
-    x1, x2, y1, y2 = map(ord, f.read(4))
+    x1, x2, y1, y2 = _map_ord(f.read(4))
     x = x1 | x2 << 7
     y = y1 | y2 << 7
 
@@ -89,8 +97,9 @@ def read_point(f, ymax):
 
 def emit_header(f):
     id, version, width, height, page_type = struct.unpack('<32sBHHBxx', f.read(40))
+    id = id.decode()
 
-    print '''
+    print('''
 <svg viewBox="0 0 %(width)s %(height)s" fill="none" stroke="black" stroke-width="10" stroke-linecap="round" stroke-linejoin="round"
   xmlns="http://www.w3.org/2000/svg"
   xmlns:svg="http://www.w3.org/2000/svg"
@@ -107,14 +116,14 @@ def emit_header(f):
       </dm:page>
     </metadata>
     <rect width="%(width)s" height="%(height)s" fill="aliceblue"/>
-''' % locals()
+''' % locals())
 
     return height
 
 
 def emit_element(message):
     if message:
-        print '%s\n' % message
+        print('%s\n' % message)
 
 
 if __name__ == '__main__':
@@ -123,6 +132,6 @@ if __name__ == '__main__':
     if len(sys.argv) == 2:
         process_file(sys.argv[1])
     else:
-        print >> sys.stderr, 'Usage: %s <dhw-file>' % sys.argv[0]
+        print('Usage: %s <dhw-file>' % sys.argv[0], file=sys.stderr)
         
 # vim: expandtab shiftwidth=4 tabstop=8 softtabstop=4 fileencoding=utf-8 textwidth=99
