@@ -31,6 +31,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 '''
 # standard library
+import sys
 import math
 # local library
 import inkex
@@ -49,7 +50,9 @@ except:
     inkex.errormsg(_("Failed to import the numpy or numpy.linalg modules. These modules are required by this extension. Please install them and try again."))
     inkex.sys.exit()
 
-def pointdistance((x1,y1),(x2,y2)):
+def pointdistance(_x1_y1, _x2_y2):
+    (x1, y1) = _x1_y1
+    (x2, y2) = _x2_y2
     return math.sqrt(((x2 - x1) ** 2) + ((y2 - y1) ** 2))
 
 def get_fit(u, csp, col):
@@ -99,7 +102,8 @@ class MyEffect(inkex.Effect):
         self.d = array([0], float)              # knot vector
         self.poly = [[0.0,0.0]]                 # LWPOLYLINE data
     def output(self):
-        print ''.join(self.dxf)
+        stdout = sys.stdout if sys.version_info[0] < 3 else sys.stdout.buffer
+        stdout.write(b''.join(self.dxf) + b'\n')
     def dxf_add(self, str):
         self.dxf.append(str.encode(self.options.char_encode))
     def dxf_line(self,csp):
@@ -194,7 +198,7 @@ class MyEffect(inkex.Effect):
         style = node.get('style')
         if style:
             style = simplestyle.parseStyle(style)
-            if style.has_key('stroke'):
+            if 'stroke' in style:
                 if style['stroke'] and style['stroke'] != 'none' and style['stroke'][0:3] != 'url':
                     rgb = simplestyle.parseColor(style['stroke'])
         hsl = coloreffect.ColorEffect.rgb_to_hsl(coloreffect.ColorEffect(),rgb[0]/255.0,rgb[1]/255.0,rgb[2]/255.0)
@@ -286,7 +290,7 @@ class MyEffect(inkex.Effect):
             style = group.get('style')
             if style:
                 style = simplestyle.parseStyle(style)
-                if style.has_key('display'):
+                if 'display' in style:
                     if style['display'] == 'none' and self.options.layer_option and self.options.layer_option=='visible':
                         return
             layer = group.get(inkex.addNS('label', 'inkscape'))
@@ -340,9 +344,17 @@ class MyEffect(inkex.Effect):
         scale = eval(self.options.units)
         if not scale:
             scale = 25.4/96     # if no scale is specified, assume inch as baseunit
-        h = self.unittouu(self.document.getroot().xpath('@height', namespaces=inkex.NSS)[0])
-        self.groupmat = [[[scale, 0.0, 0.0], [0.0, -scale, h*scale]]]
+        scale /= self.unittouu('1px')
+        h = self.unittouu(self.getDocumentHeight())
         doc = self.document.getroot()
+        # process viewBox height attribute to correct page scaling
+        viewBox = doc.get('viewBox')
+        if viewBox:
+            viewBox2 = viewBox.split(',')
+            if len(viewBox2) < 4:
+                viewBox2 = viewBox.split(' ')
+            scale *= h / self.unittouu(self.addDocumentUnit(viewBox2[3]))
+        self.groupmat = [[[scale, 0.0, 0.0], [0.0, -scale, h*scale]]]
         self.process_group(doc)
         if self.options.ROBO == 'true':
             self.ROBO_output()
