@@ -137,9 +137,12 @@ def get_obj_data(obj, name):
     if obj.name == '':#no name was found, use filename, without extension (.obj)
         obj.name = name[0:-4]
 
+    infile.close()
+
 #RENDERING AND SVG OUTPUT FUNCTIONS
 
-def draw_SVG_dot((cx, cy), st, name, parent):
+def draw_SVG_dot(_cx_cy, st, name, parent):
+    (cx, cy) = _cx_cy
     style = { 'stroke': '#000000', 'stroke-width':str(st.th), 'fill': st.fill, 'stroke-opacity':st.s_opac, 'fill-opacity':st.f_opac}
     circ_attribs = {'style':simplestyle.formatStyle(style),
                     inkex.addNS('label','inkscape'):name,
@@ -147,7 +150,9 @@ def draw_SVG_dot((cx, cy), st, name, parent):
                     'cx':str(cx), 'cy':str(-cy)}
     inkex.etree.SubElement(parent, inkex.addNS('circle','svg'), circ_attribs )
     
-def draw_SVG_line((x1, y1),(x2, y2), st, name, parent):
+def draw_SVG_line(_x1_y1, _x2_y2, st, name, parent):
+    (x1, y1) = _x1_y1
+    (x2, y2) = _x2_y2
     style = { 'stroke': '#000000', 'stroke-width':str(st.th), 'stroke-linecap':st.linecap}
     line_attribs = {'style':simplestyle.formatStyle(style),
                     inkex.addNS('label','inkscape'):name,
@@ -186,11 +191,12 @@ def draw_faces( faces_data, pts, obj, shading, fill_col,st, parent):
         face_no = face[3]#the number of the face to draw
         draw_SVG_poly(pts, obj.fce[ face_no ], st, 'Face:'+str(face_no), parent)
 
-def get_darkened_colour( (r,g,b), factor):
+def get_darkened_colour(_r_g_b, factor):
 #return a hex triplet of colour, reduced in lightness proportionally to a value between 0 and 1
-    return  '#' + "%02X" % floor( factor*r ) \
-                + "%02X" % floor( factor*g ) \
-                + "%02X" % floor( factor*b ) #make the colour string
+    (r, g, b) = _r_g_b
+    return  '#' + "%02X" % int( factor*r ) \
+                + "%02X" % int( factor*g ) \
+                + "%02X" % int( factor*b ) #make the colour string
 
 def make_rotation_log(options):
 #makes a string recording the axes and angles of each roation, so an object can be repeated
@@ -518,7 +524,7 @@ class Poly_3D(inkex.Effect):
                     if so.back or norm[2] > 0: # include all polygons or just the front-facing ones as needed
                         z_list.append((z_sort_param, angle, norm, i))#record the maximum z-value of the face and angle to light, along with the face ID and normal
                 
-                z_list.sort(lambda x, y: cmp(x[0],y[0])) #sort by ascending sort parameter of the face
+                z_list.sort(key=lambda x: x[0]) #sort by ascending sort parameter of the face
                 draw_faces( z_list, transformed_pts, obj, so.shade, fill_col, st, poly)
 
             else:#we cannot generate a list of faces from the edges without a lot of computation
