@@ -465,6 +465,11 @@ SPDocument *SPDocument::createDoc(Inkscape::XML::Document *rdoc,
         sp_file_convert_font_name(document);
     }
 
+    /** Fix dpi (pre-92 files) **/
+    if ( !(INKSCAPE.use_gui()) && sp_version_inside_range( document->root->version.inkscape, 0, 1, 0, 92 ) ) {
+        sp_file_convert_dpi(document);
+    }
+
     return document;
 }
 
@@ -1419,7 +1424,9 @@ static SPItem *find_group_at_point(unsigned int dkey, SPGroup *group, Geom::Poin
         if (SP_IS_GROUP(o) && SP_GROUP(o)->effectiveLayerMode(dkey) != SPGroup::LAYER ) {
             SPItem *child = SP_ITEM(o);
             Inkscape::DrawingItem *arenaitem = child->get_arenaitem(dkey);
-            arenaitem->drawing().update();
+            if (arenaitem) {
+                arenaitem->drawing().update();
+            }
 
             // seen remembers the last (topmost) of groups pickable at this point
             if (arenaitem && arenaitem->pick(p, delta, 1) != NULL) {
@@ -1691,7 +1698,9 @@ void SPDocument::setModifiedSinceSave(bool modified) {
         Gtk::Window *parent = SP_ACTIVE_DESKTOP->getToplevel();
         if (parent) { // during load, SP_ACTIVE_DESKTOP may be !nullptr, but parent might still be nullptr
             SPDesktopWidget *dtw = static_cast<SPDesktopWidget *>(parent->get_data("desktopwidget"));
-            dtw->updateTitle( this->getName() );
+            if (dtw) {
+                dtw->updateTitle( this->getName() );
+            }
         }
     }
 }
