@@ -54,9 +54,6 @@ private:
     Glib::RefPtr<Glib::MainLoop> _mainloop;
     /** \brief  The document that we're working on. */
     Inkscape::UI::View::View * _doc;
-    /** \brief  A list of the IDs of all the selected objects before
-                we started to work on this document. */
-    std::list<Glib::ustring> _selected;
     /** \brief  A document cache if we were passed one. */
     Implementation::ImplementationDocumentCache * _docCache;
 
@@ -97,7 +94,7 @@ public:
     void undo (void);
     /** \brief Wait for the effect to complete if it hasn't. */
     bool wait (void);
-
+    void reselect (void);
 private:
     void runComplete (void);
     void createPrefsDialog (Gtk::Widget * controls);
@@ -107,7 +104,6 @@ private:
     void processingComplete(void);
     void documentCancel (void);
     void documentCommit (void);
-    void reselect (void);
     void genDocCache (void);
     void killDocCache (void);
 };
