@@ -10,6 +10,7 @@
 #include "extension/system.h"
 
 #include "channel.h"
+#include <Magick++.h>
 
 namespace Inkscape {
 namespace Extension {
@@ -46,7 +47,7 @@ Channel::init(void)
 		"<inkscape-extension xmlns=\"" INKSCAPE_EXTENSION_URI "\">\n"
 			"<name>" N_("Channel") "</name>\n"
 			"<id>org.inkscape.effect.bitmap.channel</id>\n"
-			"<param name=\"layer\" gui-text=\"" N_("Layer") "\" type=\"enum\" >\n"
+			"<param name=\"layer\" _gui-text=\"" N_("Layer:") "\" type=\"enum\" >\n"
 				"<_item value='Red Channel'>" N_("Red Channel") "</_item>\n"
 				"<_item value='Green Channel'>" N_("Green Channel") "</_item>\n"
 				"<_item value='Blue Channel'>" N_("Blue Channel") "</_item>\n"
@@ -62,7 +63,7 @@ Channel::init(void)
 				"<effects-menu>\n"
 					"<submenu name=\"" N_("Raster") "\" />\n"
 				"</effects-menu>\n"
-				"<menu-tip>" N_("Extract specific channel from image.") "</menu-tip>\n"
+				"<menu-tip>" N_("Extract specific channel from image") "</menu-tip>\n"
 			"</effect>\n"
 		"</inkscape-extension>\n", new Channel());
 }
