@@ -24,11 +24,13 @@
 #include <signal.h>
 #include <errno.h>
 
+#include <glibmm/i18n.h>
+#include <glibmm/regex.h>
+
 #include "libnrtype/Layout-TNG.h"
 #include <2geom/transforms.h>
 #include <2geom/rect.h>
 
-#include <glibmm/i18n.h>
 #include "sp-item.h"
 #include "sp-item-group.h"
 #include "style.h"
@@ -362,6 +364,10 @@ void LaTeXTextRenderer::sp_text_render(SPText *textobj)
             Inkscape::Text::Layout::iterator ln = li; 
             ln.nextStartOfSpan();
             Glib::ustring uspanstr = sp_te_get_string_multiline (textobj, li, ln);
+
+            // escape ampersands
+            uspanstr = Glib::Regex::create("&")->replace_literal(uspanstr, 0, "\\&", (Glib::RegexMatchFlags)0);
+
             const gchar *spanstr = uspanstr.c_str();
             if (!spanstr) {
                 continue;
