@@ -19,7 +19,7 @@
 #include <boost/scoped_ptr.hpp>
 #include <2geom/transforms.h>
 
-#include "interface.h"
+#include "ui/interface.h"
 #include "helper/png-write.h"
 #include "display/cairo-utils.h"
 #include "display/drawing.h"
@@ -34,20 +34,21 @@
 
 #include "helper/pixbuf-ops.h"
 
-// TODO look for copy-n-past duplication of this function:
+// TODO look for copy-n-paste duplication of this function:
 /**
  * Hide all items that are not listed in list, recursively, skipping groups and defs.
  */
 static void hide_other_items_recursively(SPObject *o, GSList *list, unsigned dkey)
 {
-    if ( SP_IS_ITEM(o)
-         && !SP_IS_DEFS(o)
-         && !SP_IS_ROOT(o)
-         && !SP_IS_GROUP(o)
-         && !SP_IS_USE(o)
+    SPItem *item = dynamic_cast<SPItem *>(o);
+    if ( item
+         && !dynamic_cast<SPDefs *>(item)
+         && !dynamic_cast<SPRoot *>(item)
+         && !dynamic_cast<SPGroup *>(item)
+         && !dynamic_cast<SPUse *>(item)
          && !g_slist_find(list, o) )
     {
-        SP_ITEM(o)->invoke_hide(dkey);
+        item->invoke_hide(dkey);
     }
 
     // recurse
@@ -131,6 +132,11 @@ Inkscape::Pixbuf *sp_generate_internal_bitmap(SPDocument *doc, gchar const */*fi
     // because that would not work if the shown item references something in defs
     if (items_only) {
         hide_other_items_recursively(doc->getRoot(), items_only, dkey);
+        // TODO: The following loop forces 100% opacity as required by sp_asbitmap_render() in cairo-renderer.cpp
+        //       Make it contitional if 'item_only' is ever used by other callers which need to retain opacity
+        for (GSList *item = items_only; item; item = item->next) {
+            ((SPItem *)item->data)->get_arenaitem(dkey)->setOpacity(1.0);
+        }
     }
 
     Geom::IntRect final_bbox = Geom::IntRect::from_xywh(0, 0, width, height);
