@@ -46,7 +46,10 @@ Layout::iterator Layout::_cursorXOnLineToIterator(unsigned line_index, double lo
             best_x_difference = this_x_difference;
         }
     }
-    if (best_char_index == -1) return iterator(this, char_index);
+    if (best_char_index == -1)
+        best_char_index = char_index;
+    if (best_char_index == _characters.size())
+        return end();
     return iterator(this, best_char_index);
 }
 
@@ -182,6 +185,8 @@ Layout::iterator Layout::sourceToIterator(void *source_cookie /*, Glib::ustring:
     if (_input_stream[source_index]->Type() != TEXT_SOURCE)
         return iterator(this, char_index);
 
+    if (char_index >= _characters.size())
+        return end();
     return iterator(this, char_index);
     /* This code was never used, the text_iterator argument was "NULL" in all calling code
     InputStreamTextSource const *text_source = static_cast<InputStreamTextSource const *>(_input_stream[source_index]);
@@ -286,13 +291,13 @@ Geom::Point Layout::chunkAnchorPoint(iterator const &it) const
 
     Alignment alignment = _paragraphs[_lines[_chunks[chunk_index].in_line].in_paragraph].alignment;
     if (alignment == LEFT || alignment == FULL)
-        return Geom::Point(_chunks[chunk_index].left_x, _lines[chunk_index].baseline_y);
+        return Geom::Point(_chunks[chunk_index].left_x, _lines[_chunks[chunk_index].in_line].baseline_y);
 
     double chunk_width = _getChunkWidth(chunk_index);
     if (alignment == RIGHT)
-        return Geom::Point(_chunks[chunk_index].left_x + chunk_width, _lines[chunk_index].baseline_y);
+        return Geom::Point(_chunks[chunk_index].left_x + chunk_width, _lines[_chunks[chunk_index].in_line].baseline_y);
     //centre
-    return Geom::Point(_chunks[chunk_index].left_x + chunk_width * 0.5, _lines[chunk_index].baseline_y);
+    return Geom::Point(_chunks[chunk_index].left_x + chunk_width * 0.5, _lines[_chunks[chunk_index].in_line].baseline_y);
 }
 
 Geom::Rect Layout::characterBoundingBox(iterator const &it, double *rotation) const
@@ -302,8 +307,10 @@ Geom::Rect Layout::characterBoundingBox(iterator const &it, double *rotation) co
 
     if (_path_fitted) {
         double cluster_half_width = 0.0;
-        for (int glyph_index = _characters[char_index].in_glyph ; _glyphs[glyph_index].in_character == char_index ; glyph_index++)
+        for (int glyph_index = _characters[char_index].in_glyph ; _glyphs.size() != glyph_index ; glyph_index++) {
+            if (_glyphs[glyph_index].in_character != char_index) break;
             cluster_half_width += _glyphs[glyph_index].width;
+        }
         cluster_half_width *= 0.5;
 
         double midpoint_offset = _characters[char_index].span(this).x_start + _characters[char_index].x + cluster_half_width;
@@ -497,7 +504,7 @@ void Layout::queryCursorShape(iterator const &it, Geom::Point &position, double
                 if (it._glyph_index == -1) {
                     rotation = 0.0;
                 } else if(it._glyph_index == 0) {
-                    rotation = _glyphs[0].rotation;
+                    rotation = _glyphs.empty() ? 0.0 : _glyphs[0].rotation;
                 } else{
                     rotation = _glyphs[it._glyph_index - 1].rotation;
                 }
@@ -783,7 +790,10 @@ bool Layout::iterator::nextLineCursor(int n)
                          - _parent_layout->_chunks[_parent_layout->_spans[_parent_layout->_lineToSpan(line_index)].in_chunk].left_x;
     }
     _char_index = _parent_layout->_cursorXOnLineToIterator(line_index + n, _x_coordinate)._char_index;
-    _glyph_index = _parent_layout->_characters[_char_index].in_glyph;
+    if (_char_index == _parent_layout->_characters.size())
+        _glyph_index = _parent_layout->_glyphs.size();
+    else
+        _glyph_index = _parent_layout->_characters[_char_index].in_glyph;
     return true;
 }
 
