@@ -8,11 +8,10 @@
 
 #include <cstdio>
 #include <cstdlib>
-#include <glib/gmem.h>
+#include <glib.h>
 #include "Shape.h"
 #include "livarot/sweep-event-queue.h"
 #include "livarot/sweep-tree-list.h"
-#include <libnr/nr-point-fns.h>
 
 /*
  * Shape instances handling.
@@ -21,7 +20,12 @@
  */
 
 Shape::Shape()
-  : qrsData(NULL),
+  : nbQRas(0),
+    firstQRas(-1),
+    lastQRas(-1),
+    qrsData(NULL),
+    nbInc(0),
+    maxInc(0),
     iData(NULL),
     sTree(NULL),
     sEvts(NULL),
@@ -55,10 +59,10 @@ void Shape::Affiche(void)
 {
   printf("sh=%p nbPt=%i nbAr=%i\n", this, static_cast<int>(_pts.size()), static_cast<int>(_aretes.size())); // localizing ok
   for (unsigned int i=0; i<_pts.size(); i++) {
-    printf("pt %i : x=(%f %f) dI=%i dO=%i\n",i, _pts[i].x[0], _pts[i].x[1], _pts[i].dI, _pts[i].dO); // localizing ok
+    printf("pt %u : x=(%f %f) dI=%i dO=%i\n",i, _pts[i].x[0], _pts[i].x[1], _pts[i].dI, _pts[i].dO); // localizing ok
   }
   for (unsigned int i=0; i<_aretes.size(); i++) {
-    printf("ar %i : dx=(%f %f) st=%i en=%i\n",i, _aretes[i].dx[0], _aretes[i].dx[1], _aretes[i].st, _aretes[i].en); // localizing ok
+    printf("ar %u : dx=(%f %f) st=%i en=%i\n",i, _aretes[i].dx[0], _aretes[i].dx[1], _aretes[i].st, _aretes[i].en); // localizing ok
   }
 }
 
@@ -131,7 +135,12 @@ Shape::MakeQuickRasterData (bool nVal)
       if (_has_quick_raster_data == false)
         {
           _has_quick_raster_data = true;
-          qrsData = (quick_raster_data*)realloc(qrsData, maxAr * sizeof(quick_raster_data));
+          quick_raster_data* new_qrsData = static_cast<quick_raster_data*>(realloc(qrsData, maxAr * sizeof(quick_raster_data)));
+          if (!new_qrsData) {
+              g_error("Not enough memory available for reallocating Shape::qrsData");
+          } else {
+              qrsData = new_qrsData;
+          }
         }
     }
   else
@@ -309,7 +318,7 @@ Shape::Reset (int pointCount, int edgeCount)
 }
 
 int
-Shape::AddPoint (const NR::Point x)
+Shape::AddPoint (const Geom::Point x)
 {
   if (numberOfPoints() >= maxPt)
     {
@@ -1134,7 +1143,7 @@ Shape::AddEdge (int st, int en)
     }
 
   dg_arete a;
-  a.dx = NR::Point(0, 0);
+  a.dx = Geom::Point(0, 0);
   a.st = a.en = -1;
   a.prevS = a.nextS = -1;
   a.prevE = a.nextE = -1;
@@ -1209,7 +1218,7 @@ Shape::AddEdge (int st, int en, int leF, int riF)
     }
 
   dg_arete a;
-  a.dx = NR::Point(0, 0);
+  a.dx = Geom::Point(0, 0);
   a.st = a.en = -1;
   a.prevS = a.nextS = -1;
   a.prevE = a.nextE = -1;
@@ -1552,7 +1561,7 @@ Shape::SortEdges (void)
 }
 
 int
-Shape::CmpToVert (NR::Point ax, NR::Point bx,bool as,bool bs)
+Shape::CmpToVert (Geom::Point ax, Geom::Point bx,bool as,bool bs)
 {
   int tstAX = 0;
   int tstAY = 0;
@@ -1671,10 +1680,10 @@ Shape::CmpToVert (NR::Point ax, NR::Point bx,bool as,bool bs)
   if (quadA > quadB)
     return -1;
 
-  NR::Point av, bv;
+  Geom::Point av, bv;
   av = ax;
   bv = bx;
-  double si = cross (bv, av);
+  double si = cross(av, bv);
   int tstSi = 0;
   if (si > 0.000001) tstSi = 1;
   if (si < -0.000001) tstSi = -1;
@@ -1702,7 +1711,7 @@ Shape::SortEdgesList (edge_list * list, int s, int e)
 
   int ppos = (s + e) / 2;
   int plast = ppos;
-  NR::Point pvalx = list[ppos].x;
+  Geom::Point pvalx = list[ppos].x;
   bool      pvals = list[ppos].starting;
   
   int le = s, ri = e;
@@ -2054,16 +2063,16 @@ Shape::CalcBBox (bool strict_degree)
 // other=depends on your fill rule
 // if the polygon is uncrossed, it's all the same, usually
 int
-Shape::PtWinding (const NR::Point px) const 
+Shape::PtWinding (const Geom::Point px) const 
 {
   int lr = 0, ll = 0, rr = 0;
   
   for (int i = 0; i < numberOfEdges(); i++)
   {
-    NR::Point const adir = getEdge(i).dx;
+    Geom::Point const adir = getEdge(i).dx;
 
-    NR::Point const ast = getPoint(getEdge(i).st).x;
-    NR::Point const aen = getPoint(getEdge(i).en).x;
+    Geom::Point const ast = getPoint(getEdge(i).st).x;
+    Geom::Point const aen = getPoint(getEdge(i).en).x;
     
     //int const nWeight = eData[i].weight;
     int const nWeight = 1;
@@ -2094,8 +2103,8 @@ Shape::PtWinding (const NR::Point px) const
       if (aen[1] >= px[1]) continue;
     }
 
-    NR::Point const diff = px - ast;
-    double const cote = cross(diff, adir);
+    Geom::Point const diff = px - ast;
+    double const cote = cross(adir, diff);
     if (cote == 0) continue;
     if (cote < 0) {
       if (ast[0] > px[0]) lr += nWeight;
@@ -2190,7 +2199,7 @@ bool directedEulerian(Shape const *s)
  *    \return Minimum distance from p to any of the points or edges of s.
  */
 
-double distance(Shape const *s, NR::Point const &p)
+double distance(Shape const *s, Geom::Point const &p)
 {
     if ( s->hasPoints() == false) {
         return 0.0;
@@ -2201,11 +2210,11 @@ double distance(Shape const *s, NR::Point const &p)
     ** us the distance squared; we can leave the square root
     ** until the end.
     */
-    double bdot = NR::dot(p - s->getPoint(0).x, p - s->getPoint(0).x);
+    double bdot = Geom::dot(p - s->getPoint(0).x, p - s->getPoint(0).x);
 
     for (int i = 0; i < s->numberOfPoints(); i++) {
-        NR::Point const offset( p - s->getPoint(i).x );
-        double ndot = NR::dot(offset, offset);
+        Geom::Point const offset( p - s->getPoint(i).x );
+        double ndot = Geom::dot(offset, offset);
         if ( ndot < bdot ) {
             bdot = ndot;
         }
@@ -2214,18 +2223,18 @@ double distance(Shape const *s, NR::Point const &p)
     for (int i = 0; i < s->numberOfEdges(); i++) {
         if ( s->getEdge(i).st >= 0 && s->getEdge(i).en >= 0 ) {
             /* The edge has start and end points */
-            NR::Point const st(s->getPoint(s->getEdge(i).st).x); // edge start
-            NR::Point const en(s->getPoint(s->getEdge(i).en).x); // edge end
+            Geom::Point const st(s->getPoint(s->getEdge(i).st).x); // edge start
+            Geom::Point const en(s->getPoint(s->getEdge(i).en).x); // edge end
 
-            NR::Point const d(p - st);       // vector between p and edge start
-            NR::Point const e(en - st);      // vector of the edge
-            double const el = NR::dot(e, e); // edge length
+            Geom::Point const d(p - st);       // vector between p and edge start
+            Geom::Point const e(en - st);      // vector of the edge
+            double const el = Geom::dot(e, e); // edge length
 
             /* Update bdot if appropriate */
             if ( el > 0.001 ) {
-                double const npr = NR::dot(d, e);
+                double const npr = Geom::dot(d, e);
                 if ( npr > 0 && npr < el ) {
-                    double const nl = fabs( NR::cross(d, e) );
+                    double const nl = fabs( Geom::cross(d, e) );
                     double ndot = nl * nl / el;
                     if ( ndot < bdot ) {
                         bdot = ndot;
@@ -2252,7 +2261,7 @@ double distance(Shape const *s, NR::Point const &p)
  *    \param max_l2 L2 distance.
  */
 
-bool distanceLessThanOrEqual(Shape const *s, NR::Point const &p, double const max_l2)
+bool distanceLessThanOrEqual(Shape const *s, Geom::Point const &p, double const max_l2)
 {
     if ( s->hasPoints() == false ) {
         return false;
@@ -2270,25 +2279,25 @@ bool distanceLessThanOrEqual(Shape const *s, NR::Point const &p, double const ma
   
     double const max_l1 = max_l2 * M_SQRT2;
     for (int i = 0; i < s->numberOfPoints(); i++) {
-        NR::Point const offset( p - s->getPoint(i).x );
-        double const l1 = NR::L1(offset);
-        if ( (l1 <= max_l2) || ((l1 <= max_l1) && (NR::L2(offset) <= max_l2)) ) {
+        Geom::Point const offset( p - s->getPoint(i).x );
+        double const l1 = Geom::L1(offset);
+        if ( (l1 <= max_l2) || ((l1 <= max_l1) && (Geom::L2(offset) <= max_l2)) ) {
             return true;
         }
     }
     
     for (int i = 0; i < s->numberOfEdges(); i++) {
         if ( s->getEdge(i).st >= 0 && s->getEdge(i).en >= 0 ) {
-            NR::Point const st(s->getPoint(s->getEdge(i).st).x);
-            NR::Point const en(s->getPoint(s->getEdge(i).en).x);
-            NR::Point const d(p - st);
-            NR::Point const e(en - st);
-            double const el = NR::L2(e);
+            Geom::Point const st(s->getPoint(s->getEdge(i).st).x);
+            Geom::Point const en(s->getPoint(s->getEdge(i).en).x);
+            Geom::Point const d(p - st);
+            Geom::Point const e(en - st);
+            double const el = Geom::L2(e);
             if ( el > 0.001 ) {
-                NR::Point const e_unit(e / el);
-                double const npr = NR::dot(d, e_unit);
+                Geom::Point const e_unit(e / el);
+                double const npr = Geom::dot(d, e_unit);
                 if ( npr > 0 && npr < el ) {
-                    double const nl = fabs(NR::cross(d, e_unit));
+                    double const nl = fabs(Geom::cross(d, e_unit));
                     if ( nl <= max_l2 ) {
                         return true;
                     }
