@@ -4,15 +4,12 @@
 /*
  * Inkscape::LivePathEffectParameters
  *
-* Copyright (C) Johan Engelen 2007 <j.b.c.engelen@utwente.nl>
+ * Copyright (C) Johan Engelen 2007 <j.b.c.engelen@utwente.nl>
  *
  * Released under GNU GPL, read the file 'COPYING' for more information
  */
 
-#include <glib/gtypes.h>
-
-#include "ui/widget/registry.h"
-#include "ui/widget/registered-widget.h"
+#include <glib.h>
 
 #include "live_effects/parameter/parameter.h"
 
@@ -28,18 +25,21 @@ public:
                const Glib::ustring& key,
                Inkscape::UI::Widget::Registry* wr,
                Effect* effect,
-               bool default_value = false);
+               bool default_value = false,
+               bool no_widget = false);
     virtual ~BoolParam();
 
-    virtual Gtk::Widget * param_newWidget(Gtk::Tooltips * tooltips);
+    virtual Gtk::Widget * param_newWidget();
 
     virtual bool param_readSVGValue(const gchar * strvalue);
-    virtual gchar * param_writeSVGValue() const;
+    virtual gchar * param_getSVGValue() const;
 
     void param_setValue(bool newvalue);
     virtual void param_set_default();
 
-    bool get_value() { return value; };
+    bool get_value() const { return value; };
+
+    inline operator bool() const { return value; };
 
 private:
     BoolParam(const BoolParam&);
@@ -47,6 +47,7 @@ private:
 
     bool value;
     bool defvalue;
+    bool hide_widget;
 };
 
 
