@@ -8,13 +8,9 @@
 template<class T>
 inline void remove_last(std::vector<T> &seq, T const &elem)
 {
-    using std::vector;
-
-    typename vector<T>::reverse_iterator i(find(seq.rbegin(), seq.rend(), elem));
+    typename std::vector<T>::reverse_iterator i(find(seq.rbegin(), seq.rend(), elem));
     g_assert( i != seq.rend() );
-    //typename vector<T>::iterator ii(&*i);
-    //seq.erase(ii);
-	seq.erase(i.base());
+    seq.erase(i.base());
 }
 
 
@@ -30,4 +26,4 @@ inline void remove_last(std::vector<T> &seq, T const &elem)
   fill-column:99
   End:
 */
-// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:fileencoding=utf-8:textwidth=99 :
