@@ -36,6 +36,7 @@
 
 #include "helper/action.h"
 #include "helper/action-context.h"
+#include "dir-util.h"
 #include "io/sys.h"
 #include "io/resource.h"
 #include "verbs.h"
@@ -56,7 +57,7 @@ using Inkscape::IO::Resource::SYSTEM;
 using Inkscape::IO::Resource::USER;
 using Inkscape::IO::Resource::KEYS;
 
-static void try_shortcuts_file(char const *filename);
+static bool try_shortcuts_file(char const *filename, bool const is_user_set=false);
 static void read_shortcuts_file(char const *filename, bool const is_user_set=false);
 
 unsigned int sp_shortcut_get_key(unsigned int const shortcut);
@@ -84,28 +85,62 @@ static std::map<Inkscape::Verb *, unsigned int> *user_shortcuts = NULL;
 
 void sp_shortcut_init()
 {
-
     verbs = new std::map<unsigned int, Inkscape::Verb * >();
     primary_shortcuts = new std::map<Inkscape::Verb *, unsigned int>();
     user_shortcuts = new std::map<Inkscape::Verb *, unsigned int>();
 
+    // try to load shortcut file as set in preferences
+    // if preference is unset or loading fails fallback to share/keys/default.xml and finally share/keys/inkscape.xml
+    // make paths relative to share/keys/ if possible (handle parallel installations of Inkscape gracefully)
     Inkscape::Preferences *prefs = Inkscape::Preferences::get();
-    Glib::ustring shortcutfile = prefs->getString("/options/kbshortcuts/shortcutfile");
+    std::string shortcutfile = prefs->getString("/options/kbshortcuts/shortcutfile");
+    bool success = false;
+    gchar const *reason;
     if (shortcutfile.empty()) {
-        shortcutfile  = Glib::ustring(get_path(SYSTEM, KEYS, "default.xml"));
+        reason = "No key file set in preferences";
+    } else {
+        reason = "Unable to read key file set in preferences";
+        
+        bool absolute = Glib::path_is_absolute(shortcutfile);
+        if (absolute) {
+            success = try_shortcuts_file(shortcutfile.c_str());
+        } else {
+            success = try_shortcuts_file(get_path(SYSTEM, KEYS, shortcutfile.c_str()));
+        }
+
+        // store shortcutfile location relative to INKSCAPE_DATADIR
+        if (absolute && success) {
+            shortcutfile = sp_relative_path_from_path(shortcutfile, std::string(get_path(SYSTEM, KEYS)));
+            prefs->setString("/options/kbshortcuts/shortcutfile", shortcutfile.c_str());
+        }
+    }
+    if (!success) {
+        g_info("%s. Falling back to 'default.xml'.", reason);
+        success = try_shortcuts_file(get_path(SYSTEM, KEYS, "default.xml"));
+    }
+    if (!success) {
+        g_info("Could not load 'default.xml' either. Falling back to 'inkscape.xml'.");
+        success = try_shortcuts_file(get_path(SYSTEM, KEYS, "inkscape.xml"));
+    }
+    if (!success) {
+        g_warning("Could not load any keyboard shortcut file (including fallbacks to 'default.xml' and 'inkscape.xml').");
     }
 
-    read_shortcuts_file(shortcutfile.c_str());
-    try_shortcuts_file(get_path(USER, KEYS, "default.xml"));
+    // load shortcuts adjusted by user
+    try_shortcuts_file(get_path(USER, KEYS, "default.xml"), true);
 }
 
-static void try_shortcuts_file(char const *filename) {
+static bool try_shortcuts_file(char const *filename, bool const is_user_set) {
     using Inkscape::IO::file_test;
 
     /* ah, if only we had an exception to catch... (permission, forgiveness) */
     if (file_test(filename, G_FILE_TEST_EXISTS)) {
-        read_shortcuts_file(filename, true);
+        read_shortcuts_file(filename, is_user_set);
+        return true;
     }
+
+    g_info("Unable to read keyboard shortcuts from %s (does not exist)", filename);
+    return false;
 }
 
 /*
@@ -246,7 +281,13 @@ void sp_shortcut_get_file_names(std::vector<Glib::ustring> *names, std::vector<G
                         continue;
                     }
                     if (g_str_has_suffix(lower, ".xml")) {
-                        gchar* full = g_build_filename(dirname, filename, NULL);
+                        gchar *full = g_build_filename(dirname, filename, NULL);
+                        gchar *relative;
+                        if (strcmp(dirname, INKSCAPE_KEYSDIR)) {
+                            relative = g_strdup(full);
+                        } else {
+                            relative = g_strdup(filename);
+                        }
                         if (!Inkscape::IO::file_test(full, G_FILE_TEST_IS_DIR)) {
 
                         	// Get the "key name" from the root element of each file
@@ -269,16 +310,17 @@ void sp_shortcut_get_file_names(std::vector<Glib::ustring> *names, std::vector<G
                             }
 
                             if (!strcmp(filename, "default.xml")) {
-                                paths->insert(paths->begin(), full);
+                                paths->insert(paths->begin(), relative);
                                 names->insert(names->begin(), label.c_str());
                             } else {
-                                paths->push_back(full);
+                                paths->push_back(relative);
                                 names->push_back(label.c_str());
                             }
 
                             Inkscape::GC::release(doc);
                         }
                         g_free(full);
+                        g_free(relative);
                     }
                     g_free(lower);
                 }
@@ -375,7 +417,7 @@ bool sp_shortcut_file_import() {
                  open_path,
                  Inkscape::UI::Dialog::CUSTOM_TYPE,
                  _("Select a file to import"));
-        importFileDialog->addFilterMenu("All Files", "*");
+    importFileDialog->addFilterMenu(_("Inkscape shortcuts (*.xml)"), "*.xml");
 
     //# Show the dialog
     bool const success = importFileDialog->show();
@@ -588,6 +630,10 @@ static void read_shortcuts_file(char const *filename, bool const is_user_set) {
                 && strcmp(verb_name, "ToolPaintBucket")  != 0
                 && strcmp(verb_name, "SelectionTrace")   != 0
                 && strcmp(verb_name, "PaintBucketPrefs") != 0
+#endif
+#if !HAVE_ASPELL
+                && strcmp(verb_name, "DialogSpellcheck") != 0
+
 #endif
            ) {
             g_warning("Unknown verb name: %s", verb_name);
