@@ -2,8 +2,10 @@
 #define SEEN_SP_FILTER_REFERENCE_H
 
 #include "uri-references.h"
-#include "sp-filter-fns.h"
+
 class SPObject;
+class SPDocument;
+class SPFilter;
 
 class SPFilterReference : public Inkscape::URIReference {
 public:
@@ -11,14 +13,13 @@ public:
     SPFilterReference(SPDocument *doc) : URIReference(doc) {}
 
     SPFilter *getObject() const {
-        return (SPFilter *)URIReference::getObject();
+        return static_cast<SPFilter *>(URIReference::getObject());
     }
 
 protected:
     virtual bool _acceptObject(SPObject *obj) const;
 };
 
-
 #endif /* !SEEN_SP_FILTER_REFERENCE_H */
 
 /*
@@ -30,4 +31,4 @@ protected:
   fill-column:99
   End:
 */
-// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:fileencoding=utf-8:textwidth=99 :
