@@ -26,6 +26,7 @@
 #include "live_effects/lpeobject-reference.h"
 
 #include "sp-path.h"
+#include "sp-root.h"
 #include "sp-item-group.h"
 #include "streq.h"
 #include "macros.h"
@@ -35,6 +36,7 @@
 #include "uri.h"
 #include "message-stack.h"
 #include "inkscape.h"
+#include "document.h"
 #include "desktop.h"
 #include "ui/shape-editor.h"
 #include "sp-ellipse.h"
@@ -185,9 +187,9 @@ void SPLPEItem::update(SPCtx* ctx, unsigned int flags) {
 }
 
 void SPLPEItem::modified(unsigned int flags) {
-    if (SP_IS_GROUP(this) && (flags & SP_OBJECT_MODIFIED_FLAG) && (flags & SP_OBJECT_USER_MODIFIED_FLAG_B)) {
-        sp_lpe_item_update_patheffect(this, true, true);
-    }
+    //if (SP_IS_GROUP(this) && (flags & SP_OBJECT_MODIFIED_FLAG) && (flags & SP_OBJECT_USER_MODIFIED_FLAG_B)) {
+        //sp_lpe_item_update_patheffect(this, true, true);
+    //}
 
 //    SPItem::onModified(flags);
 }
@@ -405,8 +407,9 @@ void SPLPEItem::addPathEffect(std::string value, bool reset)
     if (!value.empty()) {
         // Apply the path effects here because in the casse of a group, lpe->resetDefaults
         // needs that all the subitems have their effects applied
-        sp_lpe_item_update_patheffect(this, false, true);
-
+        if (SP_IS_GROUP(this)) {
+          //  sp_lpe_item_update_patheffect(this, false, true);
+        }
         // Disable the path effects while preparing the new lpe
         sp_lpe_item_enable_path_effects(this, false);
 
@@ -424,9 +427,7 @@ void SPLPEItem::addPathEffect(std::string value, bool reset)
         if( SP_IS_GENERICELLIPSE(this)) {
             SP_GENERICELLIPSE(this)->write( this->getRepr()->document(), this->getRepr(), SP_OBJECT_WRITE_EXT );
         }
-        // make sure there is an original-d for paths!!!
-        sp_lpe_item_create_original_path_recursive(this);
-
+        
         LivePathEffectObject *lpeobj = this->path_effect_list->back()->lpeobject;
         if (lpeobj && lpeobj->get_lpe()) {
             Inkscape::LivePathEffect::Effect *lpe = lpeobj->get_lpe();
@@ -435,7 +436,10 @@ void SPLPEItem::addPathEffect(std::string value, bool reset)
                 // has to be called when all the subitems have their lpes applied
                 lpe->resetDefaults(this);
             }
-
+            // Moved here to fix #1299461, we can call previious function twice after
+            // if anyone find necesary
+            // make sure there is an original-d for paths!!!
+            sp_lpe_item_create_original_path_recursive(this);
             // perform this once when the effect is applied
             lpe->doOnApply(this);
 
@@ -662,48 +666,53 @@ SPLPEItem::apply_to_clip_or_mask(SPItem *clip_mask, SPItem *item)
             apply_to_clip_or_mask(subitem, item);
         }
     } else if (SP_IS_SHAPE(clip_mask)) {
-        SPCurve * c = NULL;
-
-        if (SP_IS_PATH(clip_mask)) {
-            c = SP_PATH(clip_mask)->get_original_curve();
+        SPRoot *root = this->document->getRoot();
+        if (sp_version_inside_range(root->version.inkscape, 0, 1, 0, 92)) {
+            clip_mask->getRepr()->setAttribute("inkscape:original-d" , NULL);
         } else {
-            c = SP_SHAPE(clip_mask)->getCurve();
-        }
-        if (c) {
-            bool success = false;
-            try {
-                if(SP_IS_GROUP(this)){
-                    c->transform(i2anc_affine(SP_GROUP(item), SP_GROUP(this)));
-                    success = this->performPathEffect(c, true);
-                    c->transform(i2anc_affine(SP_GROUP(item), SP_GROUP(this)).inverse());
-                } else {
-                    success = this->performPathEffect(c, true);
-                }
-            } catch (std::exception & e) {
-                g_warning("Exception during LPE execution. \n %s", e.what());
-                if (SP_ACTIVE_DESKTOP && SP_ACTIVE_DESKTOP->messageStack()) {
-                    SP_ACTIVE_DESKTOP->messageStack()->flash( Inkscape::WARNING_MESSAGE,
-                                    _("An exception occurred during execution of the Path Effect.") );
-                }
-                success = false;
-            }
-            Inkscape::XML::Node *repr = clip_mask->getRepr();
-            if (success) {
-                gchar *str = sp_svg_write_path(c->get_pathvector());
-                repr->setAttribute("d", str);
-                g_free(str);
+            SPCurve * c = NULL;
+
+            if (SP_IS_PATH(clip_mask)) {
+                c = SP_PATH(clip_mask)->get_original_curve();
             } else {
-                // LPE was unsuccesfull. Read the old 'd'-attribute.
-                if (gchar const * value = repr->attribute("d")) {
-                    Geom::PathVector pv = sp_svg_read_pathv(value);
-                    SPCurve *oldcurve = new SPCurve(pv);
-                    if (oldcurve) {
-                        SP_SHAPE(clip_mask)->setCurve(oldcurve, TRUE);
-                        oldcurve->unref();
+                c = SP_SHAPE(clip_mask)->getCurve();
+            }
+            if (c) {
+                bool success = false;
+                try {
+                    if(SP_IS_GROUP(this)){
+                        c->transform(i2anc_affine(SP_GROUP(item), SP_GROUP(this)));
+                        success = this->performPathEffect(c, true);
+                        c->transform(i2anc_affine(SP_GROUP(item), SP_GROUP(this)).inverse());
+                    } else {
+                        success = this->performPathEffect(c, true);
+                    }
+                } catch (std::exception & e) {
+                    g_warning("Exception during LPE execution. \n %s", e.what());
+                    if (SP_ACTIVE_DESKTOP && SP_ACTIVE_DESKTOP->messageStack()) {
+                        SP_ACTIVE_DESKTOP->messageStack()->flash( Inkscape::WARNING_MESSAGE,
+                                        _("An exception occurred during execution of the Path Effect.") );
+                    }
+                    success = false;
+                }
+                Inkscape::XML::Node *repr = clip_mask->getRepr();
+                if (success) {
+                    gchar *str = sp_svg_write_path(c->get_pathvector());
+                    repr->setAttribute("d", str);
+                    g_free(str);
+                } else {
+                    // LPE was unsuccesfull. Read the old 'd'-attribute.
+                    if (gchar const * value = repr->attribute("d")) {
+                        Geom::PathVector pv = sp_svg_read_pathv(value);
+                        SPCurve *oldcurve = new SPCurve(pv);
+                        if (oldcurve) {
+                            SP_SHAPE(clip_mask)->setCurve(oldcurve, TRUE);
+                            oldcurve->unref();
+                        }
                     }
                 }
+                c->unref();
             }
-            c->unref();
         }
     }
 }
