@@ -70,7 +70,7 @@ public:
     virtual const char* displayName() const;
 	virtual char* description() const;
 
-	virtual void set_shape();
+	virtual void set_shape(bool lpeupd = true);
 	virtual void update_patheffect(bool write);
 
 private:
