@@ -1002,50 +1002,30 @@ Geom::PathVector* item_outline(SPItem const *item, bool bbox_only)
     res->SetBackData(false);
 
     if (!i_style->stroke_dasharray.values.empty()) {
-        // For dashed strokes, use Stroke method, because Outline can't do dashes
-        // However Stroke adds lots of extra nodes _or_ makes the path crooked, so consider this a temporary workaround
-
-        orig->ConvertWithBackData(0.1);
+        double size = Geom::L2(Geom::bounds_fast(pathv)->dimensions());
+        orig->ConvertWithBackData(0.005);
 
         orig->DashPolylineFromStyle(i_style, scale, 0);
-
-        Shape* theShape = new Shape;
-        orig->Stroke(theShape, false, 0.5*o_width, o_join, o_butt,
-                     0.5 * o_miter);
-        orig->Outline(res, 0.5 * o_width, o_join, o_butt, 0.5 * o_miter);
-
-        if (!bbox_only) {
-            Shape *theRes = new Shape;
-            theRes->ConvertToShape(theShape, fill_positive);
-
-            Path *originaux[1];
-            originaux[0] = res;
-            theRes->ConvertToForme(orig, 1, originaux);
-            res->Coalesce(5.0);
-            delete theRes;
-        }
-        delete theShape;
-    } else {
-        orig->Outline(res, 0.5 * o_width, o_join, o_butt, 0.5 * o_miter);
-
-        if (!bbox_only) {
-            orig->Coalesce(0.5 * o_width);
-            Shape *theShape = new Shape;
-            Shape *theRes = new Shape;
-
-            res->ConvertWithBackData(1.0);
-            res->Fill(theShape, 0);
-            theRes->ConvertToShape(theShape, fill_positive);
-
-            Path *originaux[1];
-            originaux[0] = res;
-            theRes->ConvertToForme(orig, 1, originaux);
-
-            delete theShape;
-            delete theRes;
-        }
+        orig->Simplify(size * 0.00005);
     }
+    orig->Outline(res, 0.5 * o_width, o_join, o_butt, 0.5 * o_miter);
 
+    if (!bbox_only) {
+        orig->Coalesce(0.5 * o_width);
+        Shape *theShape = new Shape;
+        Shape *theRes = new Shape;
+
+        res->ConvertWithBackData(1.0);
+        res->Fill(theShape, 0);
+        theRes->ConvertToShape(theShape, fill_positive);
+
+        Path *originaux[1];
+        originaux[0] = res;
+        theRes->ConvertToForme(orig, 1, originaux);
+
+        delete theShape;
+        delete theRes;
+    }
     if (orig->descr_cmd.size() <= 1) {
         // ca a merd, ou bien le resultat est vide
         delete res;
@@ -1270,52 +1250,31 @@ sp_selected_path_outline(SPDesktop *desktop)
         res->SetBackData(false);
 
         if (!i_style->stroke_dasharray.values.empty()) {
-            // For dashed strokes, use Stroke method, because Outline can't do dashes
-            // However Stroke adds lots of extra nodes _or_ makes the path crooked, so consider this a temporary workaround
-
-            orig->ConvertWithBackData(0.1);
+            double size = Geom::L2(Geom::bounds_fast(pathv)->dimensions());
+            orig->ConvertWithBackData(0.005);
 
             orig->DashPolylineFromStyle(i_style, scale, 0);
-
-            Shape* theShape = new Shape;
-            orig->Stroke(theShape, false, 0.5*o_width, o_join, o_butt,
-                         0.5 * o_miter);
-            orig->Outline(res, 0.5 * o_width, o_join, o_butt, 0.5 * o_miter);
-
-            Shape *theRes = new Shape;
-
-            theRes->ConvertToShape(theShape, fill_positive);
-
-            Path *originaux[1];
-            originaux[0] = res;
-            theRes->ConvertToForme(orig, 1, originaux);
-
-            res->Coalesce(5.0);
-
-            delete theShape;
-            delete theRes;
-
-        } else {
-
-            orig->Outline(res, 0.5 * o_width, o_join, o_butt, 0.5 * o_miter);
-
-            orig->Coalesce(0.5 * o_width);
-
-            Shape *theShape = new Shape;
-            Shape *theRes = new Shape;
-
-            res->ConvertWithBackData(1.0);
-            res->Fill(theShape, 0);
-            theRes->ConvertToShape(theShape, fill_positive);
-
-            Path *originaux[1];
-            originaux[0] = res;
-            theRes->ConvertToForme(orig, 1, originaux);
-
-            delete theShape;
-            delete theRes;
+            orig->Simplify(size * 0.00005);
         }
 
+        orig->Outline(res, 0.5 * o_width, o_join, o_butt, 0.5 * o_miter);
+
+        orig->Coalesce(0.5 * o_width);
+
+        Shape *theShape = new Shape;
+        Shape *theRes = new Shape;
+
+        res->ConvertWithBackData(1.0);
+        res->Fill(theShape, 0);
+        theRes->ConvertToShape(theShape, fill_positive);
+
+        Path *originaux[1];
+        originaux[0] = res;
+        theRes->ConvertToForme(orig, 1, originaux);
+
+        delete theShape;
+        delete theRes;
+
         if (orig->descr_cmd.size() <= 1) {
             // ca a merd, ou bien le resultat est vide
             delete res;
@@ -1599,6 +1558,7 @@ void sp_selected_path_create_offset_object(SPDesktop *desktop, int expand, bool
     }
 
     Geom::Affine const transform(item->transform);
+    float scaling_factor = item->i2doc_affine().descrim();
 
     item->doWriteTransform(item->getRepr(), Geom::identity());
 
@@ -1613,12 +1573,11 @@ void sp_selected_path_create_offset_object(SPDesktop *desktop, int expand, bool
 
     float o_width = 0;
     {
-        {
-            Inkscape::Preferences *prefs = Inkscape::Preferences::get();
-            o_width = prefs->getDouble("/options/defaultoffsetwidth/value", 1.0, "px");
-        }
+        Inkscape::Preferences *prefs = Inkscape::Preferences::get();
+        o_width = prefs->getDouble("/options/defaultoffsetwidth/value", 1.0, "px");
+        o_width /= scaling_factor;
 
-        if (o_width < 0.01){
+        if (scaling_factor == 0 || o_width < 0.01) {
             o_width = 0.01;
         }
     }
@@ -1759,7 +1718,12 @@ void sp_selected_path_create_offset_object(SPDesktop *desktop, int expand, bool
 
 
 
-
+/**
+ * Apply offset to selected paths
+ * @param desktop Targetted desktop
+ * @param expand True if offset expands, False if it shrinks paths
+ * @param prefOffset Size of offset in pixels
+ */
 void
 sp_selected_path_do_offset(SPDesktop *desktop, bool expand, double prefOffset)
 {
@@ -1792,6 +1756,7 @@ sp_selected_path_do_offset(SPDesktop *desktop, bool expand, double prefOffset)
             continue;
 
         Geom::Affine const transform(item->transform);
+        float scaling_factor = item->i2doc_affine().descrim();
 
         item->doWriteTransform(item->getRepr(), Geom::identity());
 
@@ -1818,10 +1783,12 @@ sp_selected_path_do_offset(SPDesktop *desktop, bool expand, double prefOffset)
                     break;
             }
 
-            o_width = prefOffset;
+            // scale to account for transforms and document units
+            o_width = prefOffset / scaling_factor;
 
-            if (o_width < 0.1)
-                o_width = 0.1;
+            if (scaling_factor == 0 || o_width < 0.01) {
+                o_width = 0.01;
+            }
             o_miter = i_style->stroke_miterlimit.value * o_width;
         }
 
