@@ -2,7 +2,6 @@
 #define INKSCAPE_STREQ_H
 
 #include <cstring>
-#include <string>
 
 /** Convenience/readability wrapper for strcmp(a,b)==0. */
 inline bool
@@ -11,6 +10,12 @@ streq(char const *a, char const *b)
     return std::strcmp(a, b) == 0;
 }
 
+struct streq_rel {
+    bool operator()(char const *a, char const *b) const
+    {
+        return (std::strcmp(a, b) == 0);
+    }
+};
 
 #endif /* !INKSCAPE_STREQ_H */
 
@@ -23,4 +28,4 @@ streq(char const *a, char const *b)
   fill-column:99
   End:
 */
-// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:fileencoding=utf-8:textwidth=99 :
