@@ -16,6 +16,8 @@
 #include <glib.h>
 #include <iostream>
 
+#include <2geom/math-utils.h>
+
 #include "svg.h"
 #include "stringstream.h"
 #include "util/units.h"
@@ -191,6 +193,10 @@ bool SVGLength::read(gchar const *str)
         return false;
     }
 
+    if (!IS_FINITE(v)) {
+        return false;
+    }
+
     _set = true;
     unit = u;
     value = v;
