@@ -122,8 +122,11 @@ public:
     }
     virtual void notifyContentChanged( Node &/*node*/, Util::ptr_shared<char> /*old_content*/, Util::ptr_shared<char> /*new_content*/ ) {}
     virtual void notifyAttributeChanged( Node &/*node*/, GQuark name, Util::ptr_shared<char> /*old_value*/, Util::ptr_shared<char> /*new_value*/ ) {
+
+        static GQuark const _labelID = g_quark_from_string("id");
+
         if ( _pnl && _obj ) {
-            if ( name == _labelAttr ) {
+            if ( name == _labelAttr || name == _labelID ) {
                 _pnl->_updateObject( _obj);
             }
         }
@@ -334,6 +337,9 @@ bool TagsPanel::_checkForUpdated(const Gtk::TreePath &/*path*/, const Gtk::TreeI
         SPTagUse * use = SP_IS_TAG_USE(obj) ? SP_TAG_USE(obj) : 0;
         if (use && use->ref->isAttached()) {
             label = use->ref->getObject()->getAttribute("inkscape:label");
+            if (!label || !label[0]) {
+                label = use->ref->getObject()->getId();
+            }
         } else {
              label = obj->getAttribute("inkscape:label");
         }
@@ -537,7 +543,7 @@ void TagsPanel::_checkTreeSelection()
 bool TagsPanel::_handleKeyEvent(GdkEventKey *event)
 {
 
-    switch (Inkscape::UI::Tools::get_group0_keyval(event)) {
+    switch (Inkscape::UI::Tools::get_latin_keyval(event)) {
         case GDK_KEY_Return:
         case GDK_KEY_KP_Enter:
         case GDK_KEY_F2: {
@@ -814,12 +820,8 @@ void TagsPanel::_doTreeMove( )
             }
         }
         _desktop->selection->clear();
-        while (!_dnd_source.empty())
-        {
-            SPTag *src = _dnd_source.back();
-            _select_tag(src);
-            _dnd_source.pop_back();
-        }
+        // moveTo may have deleted src pointers, don't use them anymore
+        _dnd_source.clear();
         DocumentUndo::done( _desktop->doc() , SP_VERB_DIALOG_TAGS,
                                                 _("Moved sets"));
     }
