@@ -902,6 +902,11 @@ static void sp_ui_build_dyn_menus(Inkscape::XML::Node *menus, GtkWidget *menu, I
             // add filter to only open files added by Inkscape
             GtkRecentFilter *inkscape_only_filter = gtk_recent_filter_new();
             gtk_recent_filter_add_application(inkscape_only_filter, g_get_prgname());
+            gtk_recent_filter_add_application(inkscape_only_filter, "org.inkscape.Inkscape");
+            gtk_recent_filter_add_application(inkscape_only_filter, "inkscape");
+#ifdef _WIN32
+            gtk_recent_filter_add_application(inkscape_only_filter, "inkscape.exe");
+#endif
             gtk_recent_chooser_add_filter(GTK_RECENT_CHOOSER(recent_menu), inkscape_only_filter);
 
             gtk_recent_chooser_set_show_tips (GTK_RECENT_CHOOSER(recent_menu), TRUE);
@@ -2005,6 +2010,7 @@ void ContextMenu::MakeImageMenu (void)
         mi->set_sensitive( FALSE );
     }
 
+#if HAVE_POTRACE
     /* Trace Bitmap */
     mi = Gtk::manage(new Gtk::MenuItem(_("_Trace Bitmap..."), 1));
     mi->signal_activate().connect(sigc::mem_fun(*this, &ContextMenu::ImageTraceBitmap));
@@ -2013,6 +2019,7 @@ void ContextMenu::MakeImageMenu (void)
     if (_desktop->selection->isEmpty()) {
         mi->set_sensitive(FALSE);
     }
+#endif
 
     /* Trace Pixel Art */
     mi = Gtk::manage(new Gtk::MenuItem(_("Trace Pixel Art"), 1));
@@ -2133,11 +2140,13 @@ void ContextMenu::ImageEdit(void)
     }
 }
 
+#if HAVE_POTRACE
 void ContextMenu::ImageTraceBitmap(void)
 {
     INKSCAPE.dialogs_unhide();
     _desktop->_dlg_mgr->showDialog("Trace");
 }
+#endif
 
 void ContextMenu::ImageTracePixelArt(void)
 {
@@ -2211,11 +2220,13 @@ void ContextMenu::MakeTextMenu (void)
     mi->show();
     insert(*mi,positionOfLastDialog++);
 
+#if HAVE_ASPELL
     /* Spellcheck dialog */
     mi = Gtk::manage(new Gtk::MenuItem(_("Check Spellin_g..."), 1));
     mi->signal_activate().connect(sigc::mem_fun(*this, &ContextMenu::SpellcheckSettings));
     mi->show();
     insert(*mi,positionOfLastDialog++);
+#endif
 }
 
 void ContextMenu::TextSettings (void)
@@ -2229,11 +2240,13 @@ void ContextMenu::TextSettings (void)
 
 void ContextMenu::SpellcheckSettings (void)
 {
+#if HAVE_ASPELL
     if (_desktop->selection->isEmpty()) {
         _desktop->selection->set(_item);
     }
 
     _desktop->_dlg_mgr->showDialog("SpellCheck");
+#endif
 }
 
 /*
