@@ -226,9 +226,13 @@ static void spdc_paste_curve_as_freehand_shape(Geom::PathVector const &newpath,
     Effect::createAndApply(PATTERN_ALONG_PATH, dc->desktop->doc(), item);
     Effect* lpe = SP_LPE_ITEM(item)->getCurrentLPE();
     static_cast<LPEPatternAlongPath*>(lpe)->pattern.set_new_value(newpath,true);
-    double scale_doc = 1 / dc->desktop->doc()->getDocumentScale()[0];
+    Inkscape::Preferences *prefs = Inkscape::Preferences::get();
+    double scale = prefs->getDouble("/live_effect/pap/width", 1);
+    if (!scale) {
+        scale = 1 / dc->desktop->doc()->getDocumentScale()[0];
+    }
     Inkscape::SVGOStringStream os;
-    os << scale_doc;
+    os << scale;
     lpe->getRepr()->setAttribute("prop_scale", os.str().c_str());
 }
 
@@ -263,7 +267,14 @@ static void spdc_apply_bend_shape(gchar const *svgd, FreehandBase *dc, SPItem *i
     Effect* lpe = SP_LPE_ITEM(item)->getCurrentLPE();
 
     // write bend parameters:
-    lpe->getRepr()->setAttribute("prop_scale", "1");
+    Inkscape::Preferences *prefs = Inkscape::Preferences::get();
+    double scale = prefs->getDouble("/live_effect/bend/width", 1);
+    if (!scale) {
+        scale = 1;
+    }
+    Inkscape::SVGOStringStream os;
+    os << scale;
+    lpe->getRepr()->setAttribute("prop_scale", os.str().c_str());
     lpe->getRepr()->setAttribute("scale_y_rel", "false");
     lpe->getRepr()->setAttribute("vertical", "false");
     static_cast<LPEBendPath*>(lpe)->bend_path.paste_param_path(svgd);
@@ -301,7 +312,6 @@ static void spdc_check_for_and_apply_waiting_LPE(FreehandBase *dc, SPItem *item,
             previous_shape_type = shape;
         }
         if(shape == LAST_APPLIED){
-
             shape = previous_shape_type;
             if(shape == CLIPBOARD || shape == BEND_CLIPBOARD){
                 shape = LAST_APPLIED;
@@ -347,10 +357,14 @@ static void spdc_check_for_and_apply_waiting_LPE(FreehandBase *dc, SPItem *item,
         bool shape_applied = false;
         SPCSSAttr *css_item = sp_css_attr_from_object(item, SP_STYLE_FLAG_ALWAYS);
         const char *cstroke = sp_repr_css_property(css_item, "stroke", "none");
+        const char *cfill = sp_repr_css_property(css_item, "fill", "none");
         const char *stroke_width = sp_repr_css_property(css_item, "stroke-width", "0");
         double swidth;
         sp_svg_number_read_d(stroke_width, &swidth);
-
+        swidth = prefs->getDouble("/live_effect/power_stroke/width", swidth/2);
+        if (!swidth) {
+            swidth = swidth/2;
+        }
 #define SHAPE_LENGTH 10
 #define SHAPE_HEIGHT 10
 
@@ -362,7 +376,8 @@ static void spdc_check_for_and_apply_waiting_LPE(FreehandBase *dc, SPItem *item,
             {
                 // "triangle in"
                 std::vector<Geom::Point> points(1);
-                points[0] = Geom::Point(0., swidth/2);
+                
+                points[0] = Geom::Point(0., swidth);
                 //points[0] *= i2anc_affine(static_cast<SPItem *>(item->parent), NULL).inverse();
                 spdc_apply_powerstroke_shape(points, dc, item);
 
@@ -374,7 +389,7 @@ static void spdc_check_for_and_apply_waiting_LPE(FreehandBase *dc, SPItem *item,
                 // "triangle out"
                 guint curve_length = curve->get_segment_count();
                 std::vector<Geom::Point> points(1);
-                points[0] = Geom::Point(0, swidth/2);
+                points[0] = Geom::Point(0, swidth);
                 //points[0] *= i2anc_affine(static_cast<SPItem *>(item->parent), NULL).inverse();
                 points[0][Geom::X] = (double)curve_length;
                 spdc_apply_powerstroke_shape(points, dc, item);
@@ -490,11 +505,10 @@ static void spdc_check_for_and_apply_waiting_LPE(FreehandBase *dc, SPItem *item,
         if (shape_applied) {
             // apply original stroke color as fill and unset stroke; then return
             SPCSSAttr *css = sp_repr_css_attr_new();
-
-            if (!strcmp(cstroke, "none")){
-                sp_repr_css_set_property (css, "fill", "black");
-            } else {
+            if (!strcmp(cfill, "none")) {
                 sp_repr_css_set_property (css, "fill", cstroke);
+            } else {
+                sp_repr_css_set_property (css, "fill", cfill);
             }
             sp_repr_css_set_property (css, "stroke", "none");
             sp_desktop_apply_css_recursive(item, css, true);
@@ -936,6 +950,7 @@ void spdc_create_single_dot(ToolBase *ec, Geom::Point const &pt, char const *too
     Inkscape::XML::Node *repr = xml_doc->createElement("svg:path");
     repr->setAttribute("sodipodi:type", "arc");
     SPItem *item = SP_ITEM(desktop->currentLayer()->appendChildRepr(repr));
+    item->transform = SP_ITEM(desktop->currentLayer())->i2doc_affine().inverse();
     Inkscape::GC::release(repr);
 
     // apply the tool's current style
@@ -962,6 +977,7 @@ void spdc_create_single_dot(ToolBase *ec, Geom::Point const &pt, char const *too
 
     Geom::Affine const i2d (item->i2dt_affine ());
     Geom::Point pp = pt * i2d.inverse();
+
     double rad = 0.5 * prefs->getDouble(tool_path + "/dot-size", 3.0);
     if (event_state & GDK_MOD1_MASK) {
         // TODO: We vary the dot size between 0.5*rad and 1.5*rad, where rad is the dot size
@@ -980,6 +996,7 @@ void spdc_create_single_dot(ToolBase *ec, Geom::Point const &pt, char const *too
     sp_repr_set_svg_double (repr, "sodipodi:rx", rad * stroke_width);
     sp_repr_set_svg_double (repr, "sodipodi:ry", rad * stroke_width);
     item->updateRepr();
+    item->doWriteTransform(repr, item->transform);
 
     desktop->getSelection()->set(item);
 
