@@ -55,6 +55,7 @@ ColorScales::ColorScales(SelectedColor &color, SPColorScalesMode mode)
     , _rangeLimit(255.0)
     , _updating(FALSE)
     , _dragging(FALSE)
+    , _mode(SP_COLOR_SCALES_MODE_NONE)
 {
     for (gint i = 0; i < 5; i++) {
         _l[i] = 0;
@@ -261,9 +262,18 @@ gfloat ColorScales::getScaled(const GtkAdjustment *a)
     return val;
 }
 
-void ColorScales::setScaled(GtkAdjustment *a, gfloat v)
+void ColorScales::setScaled(GtkAdjustment *a, gfloat v, bool constrained)
 {
-    gfloat val = v * gtk_adjustment_get_upper(a);
+    gdouble upper = gtk_adjustment_get_upper(a);
+    gfloat val = v * upper;
+    if (constrained) {
+        // TODO: do we want preferences for these?
+        if (upper == 255) {
+            val = round(val/16) * 16;
+        } else {
+            val = round(val/10) * 10;
+        }
+    }
     gtk_adjustment_set_value(a, val);
 }
 
