@@ -210,6 +210,7 @@ static struct {
       SP_VERB_CONTEXT_ERASER_PREFS, "/tools/eraser", _("TBD")},
     { "/tools/lpetool", "lpetool_toolbox", 0, sp_lpetool_toolbox_prep, "LPEToolToolbar",
       SP_VERB_CONTEXT_LPETOOL_PREFS, "/tools/lpetool", _("TBD")},
+    // If you change TextToolbar here, change it also in desktop-widget.cpp
     { "/tools/text",   "text_toolbox",   0, sp_text_toolbox_prep, "TextToolbar",
       SP_VERB_INVALID, 0, 0},
     { "/tools/dropper", "dropper_toolbox", 0, sp_dropper_toolbox_prep,         "DropperToolbar",
@@ -301,7 +302,6 @@ static gchar const * ui_descr =
 
         "  <toolbar name='TweakToolbar'>"
         "    <toolitem action='TweakWidthAction' />"
-        "    <separator />"
         "    <toolitem action='TweakForceAction' />"
         "    <toolitem action='TweakPressureAction' />"
         "    <separator />"
@@ -363,30 +363,26 @@ static gchar const * ui_descr =
 
         "  <toolbar name='MeasureToolbar'>"
         "    <toolitem action='MeasureFontSizeAction' />"
-        "    <separator />"
         "    <toolitem action='MeasurePrecisionAction' />"
-        "    <separator />"
         "    <toolitem action='MeasureScaleAction' />"
-        "    <separator />"
-        "    <toolitem action='MeasureOffsetAction' />"
-        "    <separator />"
         "    <toolitem action='measure_units_label' />"
         "    <toolitem action='MeasureUnitsAction' />"
+        "    <separator />"
         "    <toolitem action='MeasureIgnore1stAndLast' />"
         "    <toolitem action='MeasureInBettween' />"
         "    <toolitem action='MeasureShowHidden' />"
         "    <toolitem action='MeasureAllLayers' />"
+        "    <separator />"
         "    <toolitem action='MeasureReverse' />"
         "    <toolitem action='MeasureToPhantom' />"
         "    <toolitem action='MeasureToGuides' />"
-        "    <toolitem action='MeasureMarkDimension' />"
         "    <toolitem action='MeasureToItem' />"
+        "    <toolitem action='MeasureMarkDimension' />"
+        "    <toolitem action='MeasureOffsetAction' />"
         "  </toolbar>" 
 
         "  <toolbar name='StarToolbar'>"
-        "    <separator />"
         "    <toolitem action='StarStateAction' />"
-        "    <separator />"
         "    <toolitem action='FlatAction' />"
         "    <separator />"
         "    <toolitem action='MagnitudeAction' />"
@@ -411,10 +407,8 @@ static gchar const * ui_descr =
         "  <toolbar name='3DBoxToolbar'>"
         "    <toolitem action='3DBoxAngleXAction' />"
         "    <toolitem action='3DBoxVPXStateAction' />"
-        "    <separator />"
         "    <toolitem action='3DBoxAngleYAction' />"
         "    <toolitem action='3DBoxVPYStateAction' />"
-        "    <separator />"
         "    <toolitem action='3DBoxAngleZAction' />"
         "    <toolitem action='3DBoxVPZStateAction' />"
         "  </toolbar>"
@@ -470,6 +464,9 @@ static gchar const * ui_descr =
 
         "  <toolbar name='ArcToolbar'>"
         "    <toolitem action='ArcStateAction' />"
+        "    <toolitem action='ArcRadiusXAction' />"
+        "    <toolitem action='ArcRadiusYAction' />"
+        "    <toolitem action='ArcUnitsAction' />"
         "    <separator />"
         "    <toolitem action='ArcStartAction' />"
         "    <toolitem action='ArcEndAction' />"
@@ -483,7 +480,6 @@ static gchar const * ui_descr =
 #if HAVE_POTRACE
         "  <toolbar name='PaintbucketToolbar'>"
         "    <toolitem action='ChannelsAction' />"
-        "    <separator />"
         "    <toolitem action='ThresholdAction' />"
         "    <separator />"
         "    <toolitem action='OffsetAction' />"
@@ -529,6 +525,8 @@ static gchar const * ui_descr =
         "    <toolitem action='TextWritingModeAction' />"
         "    <separator />"
         "    <toolitem action='TextOrientationAction' />"
+        "    <separator />"
+        "    <toolitem action='TextDirectionAction' />"
         "  </toolbar>"
 
         "  <toolbar name='LPEToolToolbar'>"
@@ -593,6 +591,7 @@ static gchar const * ui_descr =
         "    <toolitem action='ConnectorAvoidAction' />"
         "    <toolitem action='ConnectorIgnoreAction' />"
         "    <toolitem action='ConnectorOrthogonalAction' />"
+        "    <separator />"
         "    <toolitem action='ConnectorCurvatureAction' />"
         "    <toolitem action='ConnectorSpacingAction' />"
         "    <toolitem action='ConnectorGraphAction' />"
@@ -1450,10 +1449,11 @@ void setup_aux_toolbox(GtkWidget *toolbox, SPDesktop *desktop)
 
 #if GTK_CHECK_VERSION(3,0,0)
             GtkWidget* holder = gtk_grid_new();
-            gtk_widget_set_name( holder, "ToolbarHolder" );
+            gtk_widget_set_name( holder, aux_toolboxes[i].ui_name );
             gtk_grid_attach( GTK_GRID(holder), kludge, 2, 0, 1, 1);
 #else
             GtkWidget* holder = gtk_table_new( 1, 3, FALSE );
+            gtk_widget_set_name( holder, aux_toolboxes[i].ui_name );
             gtk_table_attach( GTK_TABLE(holder), kludge, 2, 3, 0, 1, GTK_SHRINK, GTK_SHRINK, 0, 0 );
 #endif
 
