@@ -18,7 +18,6 @@
 #ifndef SEEN_INKSCAPE_XML_NODE_H
 #define SEEN_INKSCAPE_XML_NODE_H
 
-#include <glibmm/value.h>
 #include <glibmm/ustring.h>
 #include "gc-anchored.h"
 #include "util/list.h"
@@ -100,7 +99,7 @@ public:
      *
      * @return Name for element nodes, NULL for others
      */
-    virtual gchar const *name() const=0;
+    virtual char const *name() const=0;
     /**
      * @brief Get the integer code corresponding to the node's name
      * @return GQuark code corresponding to the name
@@ -131,7 +130,7 @@ public:
      *
      * @return The node's content
      */
-    virtual gchar const *content() const=0;
+    virtual char const *content() const=0;
     
     /**
      * @brief Get the string representation of a node's attribute
@@ -144,7 +143,7 @@ public:
      *
      * @param key The name of the node's attribute
      */
-    virtual gchar const *attribute(gchar const *key) const=0;
+    virtual char const *attribute(char const *key) const=0;
     
     /**
      * @brief Get a list of the node's attributes
@@ -168,7 +167,7 @@ public:
      * @param partial_name The string to match against all attributes
      * @return true if there is such an attribute, false otherwise
      */
-    virtual bool matchAttributeName(gchar const *partial_name) const=0;
+    virtual bool matchAttributeName(char const *partial_name) const=0;
 
     /*@}*/
     
@@ -193,7 +192,7 @@ public:
      *
      * @param value The node's new content
      */
-    virtual void setContent(gchar const *value)=0;
+    virtual void setContent(char const *value)=0;
     
     //@{
     /**
@@ -205,7 +204,7 @@ public:
      * @param value The new value of the attribute
      * @param is_interactive Ignored
      */
-    virtual void setAttribute(gchar const *key, gchar const *value, bool is_interactive=false)=0;
+    virtual void setAttribute(char const *key, char const *value, bool is_interactive=false)=0;
 
     void setAttribute(char const *key, Glib::ustring const &value, bool is_interactive=false)
     {
@@ -385,6 +384,20 @@ public:
      */
     virtual void changeOrder(Node *child, Node *after)=0;
 
+     /**
+     * @brief Remove all elements that not in src node
+     * @param src The node to check for elemments into this node
+     * @param key The attribute to use as the identity attribute
+     */
+    virtual void cleanOriginal(Node *src, gchar const *key)=0;
+
+
+     /**
+     * @brief Compare 2 nodes equality
+     * @param other The other node to compare
+     * @param recursive Recursive mode check
+     */
+    virtual bool equal(Node const *other, bool recursive)=0; 
     /**
      * @brief Merge all children of another node with the current
      *
@@ -398,8 +411,11 @@ public:
      *
      * @param src The node to merge into this node
      * @param key The attribute to use as the identity attribute
+     * @param noid If true process noid items
+     * @param key If clean callback to cleanOriginal
      */
-    virtual void mergeFrom(Node const *src, gchar const *key)=0;
+
+    virtual void mergeFrom(Node const *src, char const *key, bool extension = false, bool clean = false)=0;
     
     /*@}*/
 
@@ -470,6 +486,8 @@ public:
      * @deprecated Use synthesizeEvents(NodeObserver &) instead
      */
     virtual void synthesizeEvents(NodeEventVector const *vector, void *data)=0;
+
+    virtual void recursivePrintTree(unsigned level)=0;
     
     /*@}*/
 
